==> blake_hash-1.0.0.tar.gz: lib/src/blake.dart <==
part of blake_hash;

class Blake {
  static List<Uint8List> sigma = [
    Uint8List.fromList([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15]),
    Uint8List.fromList([14, 10, 4, 8, 9, 15, 13, 6, 1, 12, 0, 2, 11, 7, 5, 3]),
    Uint8List.fromList([11, 8, 12, 0, 5, 2, 15, 13, 10, 14, 3, 6, 7, 1, 9, 4]),
    Uint8List.fromList([7, 9, 3, 1, 13, 12, 11, 14, 2, 6, 5, 10, 4, 0, 15, 8]),
    Uint8List.fromList([9, 0, 5, 7, 2, 4, 10, 15, 14, 1, 11, 12, 6, 8, 3, 13]),
    Uint8List.fromList([2, 12, 6, 10, 0, 11, 8, 3, 4, 13, 7, 5, 15, 14, 1, 9]),
    Uint8List.fromList([12, 5, 1, 15, 14, 13, 4, 10, 0, 7, 6, 3, 9, 2, 8, 11]),
    Uint8List.fromList([13, 11, 7, 14, 12, 1, 3, 9, 5, 0, 15, 4, 8, 6, 2, 10]),
    Uint8List.fromList([6, 15, 14, 9, 11, 3, 0, 8, 12, 2, 13, 7, 1, 4, 10, 5]),
    Uint8List.fromList([10, 2, 8, 4, 7, 6, 1, 5, 15, 11, 9, 14, 3, 12, 13, 0]),
    Uint8List.fromList([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15]),
    Uint8List.fromList([14, 10, 4, 8, 9, 15, 13, 6, 1, 12, 0, 2, 11, 7, 5, 3]),
    Uint8List.fromList([11, 8, 12, 0, 5, 2, 15, 13, 10, 14, 3, 6, 7, 1, 9, 4]),
    Uint8List.fromList([7, 9, 3, 1, 13, 12, 11, 14, 2, 6, 5, 10, 4, 0, 15, 8]),
    Uint8List.fromList([9, 0, 5, 7, 2, 4, 10, 15, 14, 1, 11, 12, 6, 8, 3, 13]),
    Uint8List.fromList([2, 12, 6, 10, 0, 11, 8, 3, 4, 13, 7, 5, 15, 14, 1, 9])
  ];

  static List<int> u256 = [
    0x243f6a88,
    0x85a308d3,
    0x13198a2e,
    0x03707344,
    0xa4093822,
    0x299f31d0,
    0x082efa98,
    0xec4e6c89,
    0x452821e6,
    0x38d01377,
    0xbe5466cf,
    0x34e90c6c,
    0xc0ac29b7,
    0xc97c50dd,
    0x3f84d5b5,
    0xb5470917
  ];

  static Uint8List padding = Uint8List.fromList([
    0x80,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0
  ]);

  ByteData _block;
  int _blockOffset;
  List<int> _h;
  List<int> _zo;
  List<int> _oo;
  List<int> _length;

  void _length_carry(List<int> data) {
    for (var j = 0; j < data.length; ++j) {
      if (data[j] < 0x0100000000) {
        break;
      }
      data[j] -= 0x0100000000;
      data[j + 1] += 1;
    }
  }

  void reset() {}

  void _compress() {}

  Uint8List digest() {
    return null;
  }

  Blake update(Uint8List data) {
    var offset = 0;

    while (_blockOffset + data.length - offset >= _block.lengthInBytes) {
      for (var i = _blockOffset; i < _block.lengthInBytes;) {
        _block.setUint8(i++, data[offset++]);
      }

      _length[0] += _block.lengthInBytes * 8;
      _length_carry(_length);

      _compress();
      _blockOffset = 0;
    }

    while (offset < data.length) {
      _block.setUint8(_blockOffset++, data[offset++]);
    }
    return this;
  }
}

==> blake_hash-1.0.1.tar.gz: lib/src/blake.dart <==
part of blake_hash;

abstract class Blake {
  static List<Uint8List> sigma = [
    Uint8List.fromList([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15]),
    Uint8List.fromList([14, 10, 4, 8, 9, 15, 13, 6, 1, 12, 0, 2, 11, 7, 5, 3]),
    Uint8List.fromList([11, 8, 12, 0, 5, 2, 15, 13, 10, 14, 3, 6, 7, 1, 9, 4]),
    Uint8List.fromList([7, 9, 3, 1, 13, 12, 11, 14, 2, 6, 5, 10, 4, 0, 15, 8]),
    Uint8List.fromList([9, 0, 5, 7, 2, 4, 10, 15, 14, 1, 11, 12, 6, 8, 3, 13]),
    Uint8List.fromList([2, 12, 6, 10, 0, 11, 8, 3, 4, 13, 7, 5, 15, 14, 1, 9]),
    Uint8List.fromList([12, 5, 1, 15, 14, 13, 4, 10, 0, 7, 6, 3, 9, 2, 8, 11]),
    Uint8List.fromList([13, 11, 7, 14, 12, 1, 3, 9, 5, 0, 15, 4, 8, 6, 2, 10]),
    Uint8List.fromList([6, 15, 14, 9, 11, 3, 0, 8, 12, 2, 13, 7, 1, 4, 10, 5]),
    Uint8List.fromList([10, 2, 8, 4, 7, 6, 1, 5, 15, 11, 9, 14, 3, 12, 13, 0]),
    Uint8List.fromList([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15]),
    Uint8List.fromList([14, 10, 4, 8, 9, 15, 13, 6, 1, 12, 0, 2, 11, 7, 5, 3]),
    Uint8List.fromList([11, 8, 12, 0, 5, 2, 15, 13, 10, 14, 3, 6, 7, 1, 9, 4]),
    Uint8List.fromList([7, 9, 3, 1, 13, 12, 11, 14, 2, 6, 5, 10, 4, 0, 15, 8]),
    Uint8List.fromList([9, 0, 5, 7, 2, 4, 10, 15, 14, 1, 11, 12, 6, 8, 3, 13]),
    Uint8List.fromList([2, 12, 6, 10, 0, 11, 8, 3, 4, 13, 7, 5, 15, 14, 1, 9])
  ];

  static List<int> u256 = [
    0x243f6a88,
    0x85a308d3,
    0x13198a2e,
    0x03707344,
    0xa4093822,
    0x299f31d0,
    0x082efa98,
    0xec4e6c89,
    0x452821e6,
    0x38d01377,
    0xbe5466cf,
    0x34e90c6c,
    0xc0ac29b7,
    0xc97c50dd,
    0x3f84d5b5,
    0xb5470917
  ];

  static Uint8List padding = Uint8List.fromList([0x80, ...List.filled(127, 0)]);

  late ByteData _block;
  late int _blockOffset;
  late List<int> _h;
  late Uint8List _zo;
  late Uint8List _oo;
  late List<int> _length;

  void _length_carry(List<int> data) {
    for (var j = 0; j < data.length; ++j) {
      if (data[j] < 0x0100000000) {
        break;
      }
      data[j] -= 0x0100000000;
      data[j + 1] += 1;
    }
  }

  void reset();

  void _compress();

  Uint8List digest();

  Blake update(Uint8List data) {
    var offset = 0;

    while (_blockOffset + data.length - offset >= _block.lengthInBytes) {
      for (var i = _blockOffset; i < _block.lengthInBytes;) {
        _block.setUint8(i++, data[offset++]);
      }

      _length[0] += _block.lengthInBytes * 8;
      _length_carry(_length);

      _compress();
      _blockOffset = 0;
    }

    while (offset < data.length) {
      _block.setUint8(_blockOffset++, data[offset++]);
    }
    return this;
  }
}
